# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: onyx_otc/v2/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'onyx_otc/v2/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18onyx_otc/v2/common.proto\x12\x0bonyx_otc.v2\"\x18\n\x07\x44\x65\x63imal\x12\r\n\x05value\x18\x01 \x01(\t\"%\n\x06Spread\x12\r\n\x05\x66ront\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61\x63k\x18\x02 \x01(\t\"8\n\tButterfly\x12\r\n\x05\x66ront\x18\x01 \x01(\t\x12\x0e\n\x06middle\x18\x02 \x01(\t\x12\x0c\n\x04\x62\x61\x63k\x18\x03 \x01(\t\"~\n\x0eTradableSymbol\x12\x0e\n\x04\x66lat\x18\x01 \x01(\tH\x00\x12%\n\x06spread\x18\x02 \x01(\x0b\x32\x13.onyx_otc.v2.SpreadH\x00\x12+\n\tbutterfly\x18\x03 \x01(\x0b\x32\x16.onyx_otc.v2.ButterflyH\x00\x42\x08\n\x06symbolB\x0b\xaa\x02\x08Onyx.Otcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'onyx_otc.v2.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\010Onyx.Otc'
  _globals['_DECIMAL']._serialized_start=41
  _globals['_DECIMAL']._serialized_end=65
  _globals['_SPREAD']._serialized_start=67
  _globals['_SPREAD']._serialized_end=104
  _globals['_BUTTERFLY']._serialized_start=106
  _globals['_BUTTERFLY']._serialized_end=162
  _globals['_TRADABLESYMBOL']._serialized_start=164
  _globals['_TRADABLESYMBOL']._serialized_end=290
# @@protoc_insertion_point(module_scope)
