# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: onyx_otc/v2/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'onyx_otc/v2/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17onyx_otc/v2/types.proto\x12\x0bonyx_otc.v2*\xab\x02\n\x0cOtcErrorCode\x12\x1e\n\x1aOTC_ERROR_CODE_UNSPECIFIED\x10\x00\x12\"\n\x1eOTC_ERROR_CODE_INVALID_REQUEST\x10\x01\x12\"\n\x1eOTC_ERROR_CODE_NOT_IMPLEMENTED\x10\x02\x12\"\n\x1eOTC_ERROR_CODE_UNAUTHENTICATED\x10\x03\x12$\n OTC_ERROR_CODE_TOO_MANY_REQUESTS\x10\x04\x12!\n\x1dOTC_ERROR_CODE_NOT_SUBSCRIBED\x10\x05\x12\x1c\n\x18OTC_ERROR_CODE_FORBIDDEN\x10\x06\x12(\n$OTC_ERROR_CODE_INTERNAL_SERVER_ERROR\x10\x1e*9\n\x04Side\x12\x14\n\x10SIDE_UNSPECIFIED\x10\x00\x12\x0c\n\x08SIDE_BUY\x10\x01\x12\r\n\tSIDE_SELL\x10\x02*\x83\x01\n\x12SubscriptionStatus\x12#\n\x1fSUBSCRIPTION_STATUS_UNSPECIFIED\x10\x00\x12\"\n\x1eSUBSCRIPTION_STATUS_SUBSCRIBED\x10\x01\x12$\n SUBSCRIPTION_STATUS_UNSUBSCRIBED\x10\x02*q\n\x06Method\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x0f\n\x0bMETHOD_AUTH\x10\x01\x12\x10\n\x0cMETHOD_ORDER\x10\x02\x12\x14\n\x10METHOD_SUBSCRIBE\x10\x03\x12\x16\n\x12METHOD_UNSUBSCRIBE\x10\x04*H\n\x08\x45xchange\x12\x18\n\x14\x45XCHANGE_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x45XCHANGE_ICE\x10\x01\x12\x10\n\x0c\x45XCHANGE_CME\x10\x02*D\n\tOrderType\x12\x1a\n\x16ORDER_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17ORDER_TYPE_FILL_OR_KILL\x10\x01*\xa9\x01\n\nOrderState\x12\x1b\n\x17ORDER_STATE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bORDER_STATE_PENDING_CREATED\x10\x01\x12\x17\n\x13ORDER_STATE_CREATED\x10\x02\x12\x13\n\x0fORDER_STATE_NEW\x10\x03\x12\x16\n\x12ORDER_STATE_FILLED\x10\x06\x12\x17\n\x13ORDER_STATE_ERRORED\x10\n*\xcd\x03\n\x0cTradingError\x12\x1d\n\x19TRADING_ERROR_UNSPECIFIED\x10\x00\x12\x1c\n\x17TRADING_ERROR_FORBIDDEN\x10\x93\x03\x12\x1c\n\x17TRADING_ERROR_NOT_FOUND\x10\x94\x03\x12#\n\x1eTRADING_ERROR_TRADING_DISABLED\x10\x95\x03\x12$\n\x1fTRADING_ERROR_TRADING_SUSPENDED\x10\x96\x03\x12!\n\x1cTRADING_ERROR_NOT_SUBSCRIBED\x10\x97\x03\x12!\n\x1cTRADING_ERROR_INVALID_SYMBOL\x10\x9d\x03\x12 \n\x1bTRADING_ERROR_INVALID_VALUE\x10\xa6\x03\x12 \n\x1bTRADING_ERROR_INVALID_STATE\x10\xa8\x03\x12 \n\x1bTRADING_ERROR_INVALID_PRICE\x10\xa9\x03\x12$\n\x1fTRADING_ERROR_CONTRACT_EXPIRING\x10\xaa\x03\x12!\n\x1cTRADING_ERROR_INTERNAL_ERROR\x10\xf4\x03\x12\"\n\x1dTRADING_ERROR_NOT_IMPLEMENTED\x10\xf5\x03*\x91\x01\n\x07\x43hannel\x12\x17\n\x13\x43HANNEL_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x43HANNEL_ORDERS\x10\x01\x12\x17\n\x13\x43HANNEL_SERVER_INFO\x10\x02\x12\x13\n\x0f\x43HANNEL_TICKERS\x10\x03\x12\x0f\n\x0b\x43HANNEL_RFQ\x10\x04\x12\x1a\n\x16\x43HANNEL_ORDER_BOOK_TOP\x10\x05\x42\x0b\xaa\x02\x08Onyx.Otcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'onyx_otc.v2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\010Onyx.Otc'
  _globals['_OTCERRORCODE']._serialized_start=41
  _globals['_OTCERRORCODE']._serialized_end=340
  _globals['_SIDE']._serialized_start=342
  _globals['_SIDE']._serialized_end=399
  _globals['_SUBSCRIPTIONSTATUS']._serialized_start=402
  _globals['_SUBSCRIPTIONSTATUS']._serialized_end=533
  _globals['_METHOD']._serialized_start=535
  _globals['_METHOD']._serialized_end=648
  _globals['_EXCHANGE']._serialized_start=650
  _globals['_EXCHANGE']._serialized_end=722
  _globals['_ORDERTYPE']._serialized_start=724
  _globals['_ORDERTYPE']._serialized_end=792
  _globals['_ORDERSTATE']._serialized_start=795
  _globals['_ORDERSTATE']._serialized_end=964
  _globals['_TRADINGERROR']._serialized_start=967
  _globals['_TRADINGERROR']._serialized_end=1428
  _globals['_CHANNEL']._serialized_start=1431
  _globals['_CHANNEL']._serialized_end=1576
# @@protoc_insertion_point(module_scope)
