# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: onyx_otc/v2/responses.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'onyx_otc/v2/responses.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from onyx_otc.v2 import common_pb2 as onyx__otc_dot_v2_dot_common__pb2
from onyx_otc.v2 import types_pb2 as onyx__otc_dot_v2_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bonyx_otc/v2/responses.proto\x12\x0bonyx_otc.v2\x1a\x18onyx_otc/v2/common.proto\x1a\x17onyx_otc/v2/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"L\n\x06Trader\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x11\n\tfull_name\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\"X\n\x0bPriceAmount\x12#\n\x05price\x18\x01 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12$\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\"\xd9\x01\n\x06Ticker\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x03mid\x18\x03 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12(\n\nfull_price\x18\x04 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12+\n\raccrued_price\x18\x05 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12\x16\n\x0eproduct_symbol\x18\x06 \x01(\t\"h\n\x03\x46\x65\x65\x12\x10\n\x08\x63urrency\x18\x01 \x01(\t\x12+\n\rsigned_amount\x18\x02 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12\"\n\x04rate\x18\x03 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\"\xf4\x02\n\tExecution\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08order_id\x18\x02 \x01(\t\x12\x17\n\x0f\x63lient_order_id\x18\x03 \x01(\t\x12\x12\n\naccount_id\x18\x04 \x01(\t\x12\'\n\x08\x65xchange\x18\x05 \x01(\x0e\x32\x15.onyx_otc.v2.Exchange\x12\x0e\n\x06symbol\x18\x06 \x01(\t\x12$\n\x06\x61mount\x18\x07 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12#\n\x05price\x18\x08 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12\x1f\n\x04side\x18\t \x01(\x0e\x32\x11.onyx_otc.v2.Side\x12\x35\n\x11\x63reated_timestamp\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x03\x66\x65\x65\x18\x13 \x01(\x0b\x32\x10.onyx_otc.v2.Fee\x12!\n\x04user\x18\x14 \x01(\x0b\x32\x13.onyx_otc.v2.Trader\"/\n\x07Tickers\x12$\n\x07tickers\x18\x01 \x03(\x0b\x32\x13.onyx_otc.v2.Ticker\"\xde\x02\n\rLiveWebsocket\x12\x12\n\nsocket_uid\x18\x01 \x01(\t\x12\x18\n\x10message_received\x18\x02 \x01(\x03\x12\x14\n\x0cmessage_sent\x18\x03 \x01(\x03\x12+\n\x07started\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63urrent_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_message_received\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11last_message_sent\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x63lient_type\x18\x08 \x01(\t\x12\x11\n\tremote_ip\x18\t \x01(\t\x12\x10\n\x08protocol\x18\n \x01(\t\"i\n\nServerInfo\x12\x12\n\nsocket_uid\x18\x01 \x01(\t\x12\x12\n\nage_millis\x18\x02 \x01(\x03\x12\x33\n\x0flive_websockets\x18\x03 \x03(\x0b\x32\x1a.onyx_otc.v2.LiveWebsocket\"Y\n\x0cOtcQuoteSide\x12#\n\x05price\x18\x01 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12$\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\"\x9b\x02\n\x08OtcQuote\x12+\n\x06symbol\x18\x01 \x01(\x0b\x32\x1b.onyx_otc.v2.TradableSymbol\x12\'\n\x08\x65xchange\x18\x02 \x01(\x0e\x32\x15.onyx_otc.v2.Exchange\x12&\n\x03\x62uy\x18\x03 \x01(\x0b\x32\x19.onyx_otc.v2.OtcQuoteSide\x12\'\n\x04sell\x18\x04 \x01(\x0b\x32\x19.onyx_otc.v2.OtcQuoteSide\x12!\n\x03mid\x18\x05 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0eproduct_symbol\x18\x07 \x01(\t\"\xdd\x01\n\x0cOrderBookTop\x12%\n\x03\x62uy\x18\x01 \x01(\x0b\x32\x18.onyx_otc.v2.PriceAmount\x12&\n\x04sell\x18\x02 \x01(\x0b\x32\x18.onyx_otc.v2.PriceAmount\x12\'\n\x08\x65xchange\x18\x03 \x01(\x0e\x32\x15.onyx_otc.v2.Exchange\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0eproduct_symbol\x18\x06 \x01(\t\"C\n\rOrderBookTops\x12\x32\n\x0forder_book_tops\x18\x01 \x03(\x0b\x32\x19.onyx_otc.v2.OrderBookTop\"\x9f\x05\n\x05Order\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0f\x63lient_order_id\x18\x02 \x01(\t\x12!\n\x04user\x18\x03 \x01(\x0b\x32\x13.onyx_otc.v2.Trader\x12\x12\n\naccount_id\x18\x04 \x01(\t\x12\'\n\x08\x65xchange\x18\x05 \x01(\x0e\x32\x15.onyx_otc.v2.Exchange\x12\x16\n\x0eproduct_symbol\x18\x06 \x01(\t\x12+\n\x06symbol\x18\x07 \x01(\x0b\x32\x1b.onyx_otc.v2.TradableSymbol\x12*\n\norder_type\x18\n \x01(\x0e\x32\x16.onyx_otc.v2.OrderType\x12,\n\x0border_state\x18\x0b \x01(\x0e\x32\x17.onyx_otc.v2.OrderState\x12$\n\x06\x61mount\x18\x0c \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12(\n\x05price\x18\r \x01(\x0b\x32\x14.onyx_otc.v2.DecimalH\x00\x88\x01\x01\x12\x1f\n\x04side\x18\x10 \x01(\x0e\x32\x11.onyx_otc.v2.Side\x12\x35\n\x11\x63reated_timestamp\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12\x65xecuted_avg_price\x18\x15 \x01(\x0b\x32\x14.onyx_otc.v2.DecimalH\x01\x88\x01\x01\x12\x32\n\x0f\x65xecuted_amount\x18\x16 \x01(\x0b\x32\x14.onyx_otc.v2.DecimalH\x02\x88\x01\x01\x12*\n\nexecutions\x18\x1a \x03(\x0b\x32\x16.onyx_otc.v2.ExecutionB\x08\n\x06_priceB\x15\n\x13_executed_avg_priceB\x12\n\x10_executed_amount\"\xd2\x02\n\x0e\x43hannelMessage\x12%\n\x07\x63hannel\x18\x01 \x01(\x0e\x32\x14.onyx_otc.v2.Channel\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12#\n\x05order\x18\x08 \x01(\x0b\x32\x12.onyx_otc.v2.OrderH\x00\x12.\n\x0bserver_info\x18\t \x01(\x0b\x32\x17.onyx_otc.v2.ServerInfoH\x00\x12\'\n\x07tickers\x18\n \x01(\x0b\x32\x14.onyx_otc.v2.TickersH\x00\x12*\n\totc_quote\x18\x0b \x01(\x0b\x32\x15.onyx_otc.v2.OtcQuoteH\x00\x12\x35\n\x0forder_book_tops\x18\x0c \x01(\x0b\x32\x1a.onyx_otc.v2.OrderBookTopsH\x00\x42\t\n\x07message\"w\n\x0cSubscription\x12%\n\x07\x63hannel\x18\x01 \x01(\x0e\x32\x14.onyx_otc.v2.Channel\x12\x0f\n\x07message\x18\x02 \x01(\t\x12/\n\x06status\x18\x03 \x01(\x0e\x32\x1f.onyx_otc.v2.SubscriptionStatus\"\x1f\n\x0c\x41uthResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"D\n\x08OtcError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\'\n\x04\x63ode\x18\x02 \x01(\x0e\x32\x19.onyx_otc.v2.OtcErrorCode\"\xff\x01\n\x0bOtcResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12#\n\x05order\x18\x0b \x01(\x0b\x32\x12.onyx_otc.v2.OrderH\x00\x12\x31\n\x0csubscription\x18\x0c \x01(\x0b\x32\x19.onyx_otc.v2.SubscriptionH\x00\x12)\n\x04\x61uth\x18\x0e \x01(\x0b\x32\x19.onyx_otc.v2.AuthResponseH\x00\x12&\n\x05\x65rror\x18\r \x01(\x0b\x32\x15.onyx_otc.v2.OtcErrorH\x00\x42\n\n\x08response\"\x86\x01\n\x12OtcResponseMessage\x12\x30\n\x0cotc_response\x18\x01 \x01(\x0b\x32\x18.onyx_otc.v2.OtcResponseH\x00\x12\x36\n\x0f\x63hannel_message\x18\x02 \x01(\x0b\x32\x1b.onyx_otc.v2.ChannelMessageH\x00\x42\x06\n\x04\x64\x61taB\x0b\xaa\x02\x08Onyx.Otcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'onyx_otc.v2.responses_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\010Onyx.Otc'
  _globals['_TRADER']._serialized_start=128
  _globals['_TRADER']._serialized_end=204
  _globals['_PRICEAMOUNT']._serialized_start=206
  _globals['_PRICEAMOUNT']._serialized_end=294
  _globals['_TICKER']._serialized_start=297
  _globals['_TICKER']._serialized_end=514
  _globals['_FEE']._serialized_start=516
  _globals['_FEE']._serialized_end=620
  _globals['_EXECUTION']._serialized_start=623
  _globals['_EXECUTION']._serialized_end=995
  _globals['_TICKERS']._serialized_start=997
  _globals['_TICKERS']._serialized_end=1044
  _globals['_LIVEWEBSOCKET']._serialized_start=1047
  _globals['_LIVEWEBSOCKET']._serialized_end=1397
  _globals['_SERVERINFO']._serialized_start=1399
  _globals['_SERVERINFO']._serialized_end=1504
  _globals['_OTCQUOTESIDE']._serialized_start=1506
  _globals['_OTCQUOTESIDE']._serialized_end=1595
  _globals['_OTCQUOTE']._serialized_start=1598
  _globals['_OTCQUOTE']._serialized_end=1881
  _globals['_ORDERBOOKTOP']._serialized_start=1884
  _globals['_ORDERBOOKTOP']._serialized_end=2105
  _globals['_ORDERBOOKTOPS']._serialized_start=2107
  _globals['_ORDERBOOKTOPS']._serialized_end=2174
  _globals['_ORDER']._serialized_start=2177
  _globals['_ORDER']._serialized_end=2848
  _globals['_CHANNELMESSAGE']._serialized_start=2851
  _globals['_CHANNELMESSAGE']._serialized_end=3189
  _globals['_SUBSCRIPTION']._serialized_start=3191
  _globals['_SUBSCRIPTION']._serialized_end=3310
  _globals['_AUTHRESPONSE']._serialized_start=3312
  _globals['_AUTHRESPONSE']._serialized_end=3343
  _globals['_OTCERROR']._serialized_start=3345
  _globals['_OTCERROR']._serialized_end=3413
  _globals['_OTCRESPONSE']._serialized_start=3416
  _globals['_OTCRESPONSE']._serialized_end=3671
  _globals['_OTCRESPONSEMESSAGE']._serialized_start=3674
  _globals['_OTCRESPONSEMESSAGE']._serialized_end=3808
# @@protoc_insertion_point(module_scope)
