# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: onyx_otc/v2/requests.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'onyx_otc/v2/requests.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from onyx_otc.v2 import common_pb2 as onyx__otc_dot_v2_dot_common__pb2
from onyx_otc.v2 import types_pb2 as onyx__otc_dot_v2_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aonyx_otc/v2/requests.proto\x12\x0bonyx_otc.v2\x1a\x18onyx_otc/v2/common.proto\x1a\x17onyx_otc/v2/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd9\x02\n\x0fNewOrderRequest\x12\x1c\n\x0f\x63lient_order_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12+\n\x06symbol\x18\x03 \x01(\x0b\x32\x1b.onyx_otc.v2.TradableSymbol\x12&\n\x08quantity\x18\x0b \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12\x1f\n\x04side\x18\x0c \x01(\x0e\x32\x11.onyx_otc.v2.Side\x12*\n\norder_type\x18\x0e \x01(\x0e\x32\x16.onyx_otc.v2.OrderType\x12#\n\x05price\x18\x0f \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12,\n\x08\x65xchange\x18\x10 \x01(\x0e\x32\x15.onyx_otc.v2.ExchangeH\x01\x88\x01\x01\x42\x12\n\x10_client_order_idB\x0b\n\t_exchange\"\"\n\x0eTickersChannel\x12\x10\n\x08products\x18\x01 \x03(\t\"\x98\x01\n\nRfqChannel\x12+\n\x06symbol\x18\x01 \x01(\x0b\x32\x1b.onyx_otc.v2.TradableSymbol\x12\"\n\x04size\x18\x02 \x01(\x0b\x32\x14.onyx_otc.v2.Decimal\x12,\n\x08\x65xchange\x18\x03 \x01(\x0e\x32\x15.onyx_otc.v2.ExchangeH\x00\x88\x01\x01\x42\x0b\n\t_exchange\"\'\n\x13OrderBookTopChannel\x12\x10\n\x08products\x18\x01 \x03(\t\"\x13\n\x11ServerInfoChannel\"\x0f\n\rOrdersChannel\"\x15\n\x04\x41uth\x12\r\n\x05token\x18\x02 \x01(\t\"\x97\x02\n\tSubscribe\x12\x35\n\x0bserver_info\x18\x01 \x01(\x0b\x32\x1e.onyx_otc.v2.ServerInfoChannelH\x00\x12,\n\x06orders\x18\x02 \x01(\x0b\x32\x1a.onyx_otc.v2.OrdersChannelH\x00\x12.\n\x07tickers\x18\x03 \x01(\x0b\x32\x1b.onyx_otc.v2.TickersChannelH\x00\x12.\n\x0brfq_channel\x18\x04 \x01(\x0b\x32\x17.onyx_otc.v2.RfqChannelH\x00\x12:\n\x0eorder_book_top\x18\x05 \x01(\x0b\x32 .onyx_otc.v2.OrderBookTopChannelH\x00\x42\t\n\x07\x63hannel\"\x99\x02\n\x0bUnsubscribe\x12\x35\n\x0bserver_info\x18\x01 \x01(\x0b\x32\x1e.onyx_otc.v2.ServerInfoChannelH\x00\x12,\n\x06orders\x18\x02 \x01(\x0b\x32\x1a.onyx_otc.v2.OrdersChannelH\x00\x12.\n\x07tickers\x18\x03 \x01(\x0b\x32\x1b.onyx_otc.v2.TickersChannelH\x00\x12.\n\x0brfq_channel\x18\x04 \x01(\x0b\x32\x17.onyx_otc.v2.RfqChannelH\x00\x12:\n\x0eorder_book_top\x18\x05 \x01(\x0b\x32 .onyx_otc.v2.OrderBookTopChannelH\x00\x42\t\n\x07\x63hannel\"\xa7\x02\n\nOtcRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12#\n\x06method\x18\x03 \x01(\x0e\x32\x13.onyx_otc.v2.Method\x12!\n\x04\x61uth\x18\n \x01(\x0b\x32\x11.onyx_otc.v2.AuthH\x00\x12+\n\tsubscribe\x18\x0b \x01(\x0b\x32\x16.onyx_otc.v2.SubscribeH\x00\x12/\n\x0bunsubscribe\x18\x0c \x01(\x0b\x32\x18.onyx_otc.v2.UnsubscribeH\x00\x12-\n\x05order\x18\r \x01(\x0b\x32\x1c.onyx_otc.v2.NewOrderRequestH\x00\x42\t\n\x07requestB\x0b\xaa\x02\x08Onyx.Otcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'onyx_otc.v2.requests_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\010Onyx.Otc'
  _globals['_NEWORDERREQUEST']._serialized_start=128
  _globals['_NEWORDERREQUEST']._serialized_end=473
  _globals['_TICKERSCHANNEL']._serialized_start=475
  _globals['_TICKERSCHANNEL']._serialized_end=509
  _globals['_RFQCHANNEL']._serialized_start=512
  _globals['_RFQCHANNEL']._serialized_end=664
  _globals['_ORDERBOOKTOPCHANNEL']._serialized_start=666
  _globals['_ORDERBOOKTOPCHANNEL']._serialized_end=705
  _globals['_SERVERINFOCHANNEL']._serialized_start=707
  _globals['_SERVERINFOCHANNEL']._serialized_end=726
  _globals['_ORDERSCHANNEL']._serialized_start=728
  _globals['_ORDERSCHANNEL']._serialized_end=743
  _globals['_AUTH']._serialized_start=745
  _globals['_AUTH']._serialized_end=766
  _globals['_SUBSCRIBE']._serialized_start=769
  _globals['_SUBSCRIBE']._serialized_end=1048
  _globals['_UNSUBSCRIBE']._serialized_start=1051
  _globals['_UNSUBSCRIBE']._serialized_end=1332
  _globals['_OTCREQUEST']._serialized_start=1335
  _globals['_OTCREQUEST']._serialized_end=1630
# @@protoc_insertion_point(module_scope)
