"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _OtcErrorCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OtcErrorCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OtcErrorCode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    OTC_ERROR_CODE_UNSPECIFIED: _OtcErrorCode.ValueType  # 0
    OTC_ERROR_CODE_INVALID_REQUEST: _OtcErrorCode.ValueType  # 1
    OTC_ERROR_CODE_NOT_IMPLEMENTED: _OtcErrorCode.ValueType  # 2
    OTC_ERROR_CODE_UNAUTHENTICATED: _OtcErrorCode.ValueType  # 3
    OTC_ERROR_CODE_TOO_MANY_REQUESTS: _OtcErrorCode.ValueType  # 4
    OTC_ERROR_CODE_NOT_SUBSCRIBED: _OtcErrorCode.ValueType  # 5
    OTC_ERROR_CODE_FORBIDDEN: _OtcErrorCode.ValueType  # 6
    OTC_ERROR_CODE_INTERNAL_SERVER_ERROR: _OtcErrorCode.ValueType  # 30

class OtcErrorCode(_OtcErrorCode, metaclass=_OtcErrorCodeEnumTypeWrapper): ...

OTC_ERROR_CODE_UNSPECIFIED: OtcErrorCode.ValueType  # 0
OTC_ERROR_CODE_INVALID_REQUEST: OtcErrorCode.ValueType  # 1
OTC_ERROR_CODE_NOT_IMPLEMENTED: OtcErrorCode.ValueType  # 2
OTC_ERROR_CODE_UNAUTHENTICATED: OtcErrorCode.ValueType  # 3
OTC_ERROR_CODE_TOO_MANY_REQUESTS: OtcErrorCode.ValueType  # 4
OTC_ERROR_CODE_NOT_SUBSCRIBED: OtcErrorCode.ValueType  # 5
OTC_ERROR_CODE_FORBIDDEN: OtcErrorCode.ValueType  # 6
OTC_ERROR_CODE_INTERNAL_SERVER_ERROR: OtcErrorCode.ValueType  # 30
global___OtcErrorCode = OtcErrorCode

class _Side:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SideEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Side.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SIDE_UNSPECIFIED: _Side.ValueType  # 0
    SIDE_BUY: _Side.ValueType  # 1
    SIDE_SELL: _Side.ValueType  # 2

class Side(_Side, metaclass=_SideEnumTypeWrapper): ...

SIDE_UNSPECIFIED: Side.ValueType  # 0
SIDE_BUY: Side.ValueType  # 1
SIDE_SELL: Side.ValueType  # 2
global___Side = Side

class _SubscriptionStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SubscriptionStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SubscriptionStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SUBSCRIPTION_STATUS_UNSPECIFIED: _SubscriptionStatus.ValueType  # 0
    SUBSCRIPTION_STATUS_SUBSCRIBED: _SubscriptionStatus.ValueType  # 1
    SUBSCRIPTION_STATUS_UNSUBSCRIBED: _SubscriptionStatus.ValueType  # 2

class SubscriptionStatus(_SubscriptionStatus, metaclass=_SubscriptionStatusEnumTypeWrapper): ...

SUBSCRIPTION_STATUS_UNSPECIFIED: SubscriptionStatus.ValueType  # 0
SUBSCRIPTION_STATUS_SUBSCRIBED: SubscriptionStatus.ValueType  # 1
SUBSCRIPTION_STATUS_UNSUBSCRIBED: SubscriptionStatus.ValueType  # 2
global___SubscriptionStatus = SubscriptionStatus

class _Method:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MethodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Method.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    METHOD_UNSPECIFIED: _Method.ValueType  # 0
    METHOD_AUTH: _Method.ValueType  # 1
    METHOD_ORDER: _Method.ValueType  # 2
    METHOD_SUBSCRIBE: _Method.ValueType  # 3
    METHOD_UNSUBSCRIBE: _Method.ValueType  # 4

class Method(_Method, metaclass=_MethodEnumTypeWrapper): ...

METHOD_UNSPECIFIED: Method.ValueType  # 0
METHOD_AUTH: Method.ValueType  # 1
METHOD_ORDER: Method.ValueType  # 2
METHOD_SUBSCRIBE: Method.ValueType  # 3
METHOD_UNSUBSCRIBE: Method.ValueType  # 4
global___Method = Method

class _Exchange:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExchangeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Exchange.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXCHANGE_UNSPECIFIED: _Exchange.ValueType  # 0
    EXCHANGE_ICE: _Exchange.ValueType  # 1
    EXCHANGE_CME: _Exchange.ValueType  # 2

class Exchange(_Exchange, metaclass=_ExchangeEnumTypeWrapper): ...

EXCHANGE_UNSPECIFIED: Exchange.ValueType  # 0
EXCHANGE_ICE: Exchange.ValueType  # 1
EXCHANGE_CME: Exchange.ValueType  # 2
global___Exchange = Exchange

class _OrderType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OrderTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OrderType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ORDER_TYPE_UNSPECIFIED: _OrderType.ValueType  # 0
    ORDER_TYPE_FILL_OR_KILL: _OrderType.ValueType  # 1

class OrderType(_OrderType, metaclass=_OrderTypeEnumTypeWrapper): ...

ORDER_TYPE_UNSPECIFIED: OrderType.ValueType  # 0
ORDER_TYPE_FILL_OR_KILL: OrderType.ValueType  # 1
global___OrderType = OrderType

class _OrderState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OrderStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OrderState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ORDER_STATE_UNSPECIFIED: _OrderState.ValueType  # 0
    ORDER_STATE_PENDING_CREATED: _OrderState.ValueType  # 1
    ORDER_STATE_CREATED: _OrderState.ValueType  # 2
    ORDER_STATE_NEW: _OrderState.ValueType  # 3
    ORDER_STATE_FILLED: _OrderState.ValueType  # 6
    ORDER_STATE_ERRORED: _OrderState.ValueType  # 10

class OrderState(_OrderState, metaclass=_OrderStateEnumTypeWrapper): ...

ORDER_STATE_UNSPECIFIED: OrderState.ValueType  # 0
ORDER_STATE_PENDING_CREATED: OrderState.ValueType  # 1
ORDER_STATE_CREATED: OrderState.ValueType  # 2
ORDER_STATE_NEW: OrderState.ValueType  # 3
ORDER_STATE_FILLED: OrderState.ValueType  # 6
ORDER_STATE_ERRORED: OrderState.ValueType  # 10
global___OrderState = OrderState

class _TradingError:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TradingErrorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TradingError.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRADING_ERROR_UNSPECIFIED: _TradingError.ValueType  # 0
    TRADING_ERROR_FORBIDDEN: _TradingError.ValueType  # 403
    TRADING_ERROR_NOT_FOUND: _TradingError.ValueType  # 404
    TRADING_ERROR_TRADING_DISABLED: _TradingError.ValueType  # 405
    TRADING_ERROR_TRADING_SUSPENDED: _TradingError.ValueType  # 406
    TRADING_ERROR_NOT_SUBSCRIBED: _TradingError.ValueType  # 407
    TRADING_ERROR_INVALID_SYMBOL: _TradingError.ValueType  # 413
    TRADING_ERROR_INVALID_VALUE: _TradingError.ValueType  # 422
    TRADING_ERROR_INVALID_STATE: _TradingError.ValueType  # 424
    TRADING_ERROR_INVALID_PRICE: _TradingError.ValueType  # 425
    TRADING_ERROR_CONTRACT_EXPIRING: _TradingError.ValueType  # 426
    TRADING_ERROR_INTERNAL_ERROR: _TradingError.ValueType  # 500
    TRADING_ERROR_NOT_IMPLEMENTED: _TradingError.ValueType  # 501

class TradingError(_TradingError, metaclass=_TradingErrorEnumTypeWrapper): ...

TRADING_ERROR_UNSPECIFIED: TradingError.ValueType  # 0
TRADING_ERROR_FORBIDDEN: TradingError.ValueType  # 403
TRADING_ERROR_NOT_FOUND: TradingError.ValueType  # 404
TRADING_ERROR_TRADING_DISABLED: TradingError.ValueType  # 405
TRADING_ERROR_TRADING_SUSPENDED: TradingError.ValueType  # 406
TRADING_ERROR_NOT_SUBSCRIBED: TradingError.ValueType  # 407
TRADING_ERROR_INVALID_SYMBOL: TradingError.ValueType  # 413
TRADING_ERROR_INVALID_VALUE: TradingError.ValueType  # 422
TRADING_ERROR_INVALID_STATE: TradingError.ValueType  # 424
TRADING_ERROR_INVALID_PRICE: TradingError.ValueType  # 425
TRADING_ERROR_CONTRACT_EXPIRING: TradingError.ValueType  # 426
TRADING_ERROR_INTERNAL_ERROR: TradingError.ValueType  # 500
TRADING_ERROR_NOT_IMPLEMENTED: TradingError.ValueType  # 501
global___TradingError = TradingError

class _Channel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChannelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Channel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHANNEL_UNSPECIFIED: _Channel.ValueType  # 0
    CHANNEL_ORDERS: _Channel.ValueType  # 1
    CHANNEL_SERVER_INFO: _Channel.ValueType  # 2
    CHANNEL_TICKERS: _Channel.ValueType  # 3
    CHANNEL_RFQ: _Channel.ValueType  # 4
    CHANNEL_ORDER_BOOK_TOP: _Channel.ValueType  # 5

class Channel(_Channel, metaclass=_ChannelEnumTypeWrapper): ...

CHANNEL_UNSPECIFIED: Channel.ValueType  # 0
CHANNEL_ORDERS: Channel.ValueType  # 1
CHANNEL_SERVER_INFO: Channel.ValueType  # 2
CHANNEL_TICKERS: Channel.ValueType  # 3
CHANNEL_RFQ: Channel.ValueType  # 4
CHANNEL_ORDER_BOOK_TOP: Channel.ValueType  # 5
global___Channel = Channel
